@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 # File: __init__.py
 #
-# Copyright 2019 Yorick Hoorneman
+# Copyright 2023 Yorick Hoorneman
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 #  of this software and associated documentation files (the "Software"), to
@@ -29,16 +29,14 @@ opsgenielib package.
 Import all parts from opsgenielib here
 
 .. _Google Python Style Guide:
-   http://google.github.io/styleguide/pyguide.html
+   https://google.github.io/styleguide/pyguide.html
 """
 from ._version import __version__
-from .opsgenielib import Opsgenie
-from .opsgenielibexceptions import InvalidApiKey
 
 __author__ = '''Yorick Hoorneman <yhoorneman@schubergphilis.com>'''
 __docformat__ = '''google'''
-__date__ = '''12-04-2019'''
-__copyright__ = '''Copyright 2019, Yorick Hoorneman'''
+__date__ = '''21-03-2023'''
+__copyright__ = '''Copyright 2023, Yorick Hoorneman'''
 __license__ = '''MIT'''
 __maintainer__ = '''Yorick Hoorneman'''
 __email__ = '''<yhoorneman@schubergphilis.com>'''
@@ -46,9 +44,3 @@ __status__ = '''Development'''  # "Prototype", "Development", "Production".
 
 # This is to 'use' the module(s), so lint doesn't complain
 assert __version__
-
-# assert all exceptions
-assert InvalidApiKey
-
-# assert all objects
-assert Opsgenie
