@@ -364,7 +364,7 @@ class Opsgenie:  # pylint: disable=too-many-public-methods, too-many-instance-at
         self._logger.debug('Making a call to "%s"', url)
         response = self._session.post(url, json=payload)
         response.raise_for_status()
-        return response
+        return MaintenancePolicy(self, response.json().get('data', {}))
 
     def list_maintenance(self, non_expired=False, past=False):
         """Listing maintenance policies. Returns the json."""
@@ -516,7 +516,7 @@ class Opsgenie:  # pylint: disable=too-many-public-methods, too-many-instance-at
         return AlertPolicy(self, response.json().get('data', {}))
         
     def get_alert_policy_by_name(self, policy_name, team_id):
-        alert_policy = [policy for policy in self.list_alert_policy(team_id) if policy.name == policy_name]
+        alert_policy = [policy for policy in self.list_alert_policy(team_id) if policy.name.lower() == policy_name.lower()]
         if not alert_policy:
             raise NoAlertPolicyFound
         return next(iter(alert_policy))
